# OCR
pdf_ocr_function_arn = "arn:aws:lambda:us-east-1:689835822208:function:ocr-pdf-dev-lambda"
img_ocr_function_arn = "arn:aws:lambda:us-east-1:689835822208:function:ocr-img-dev-lambda"

# Bookkeeping
# bookkeeping_endpoint = "https://cjuwzz07ri.execute-api.us-east-1.amazonaws.com/prod"
bookkeeping_endpoint = "https://api.duke.ai/api"

# Auto
duke_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Auto-duke-prod-lambda"
rpa_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Auto-tms-prod-lambda"
ralock_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Auto-ralock-prod-lambda"

# RPA
rpa_endpoint = "https://api.duke.ai/rpa"

# Version
version = "0.3.1"
